/*******************************************************************************
 * sshtrix - a very fast multithreaded SSH login cracker                       *
 *                                                                             *
 * job.h                                                                       *
 *                                                                             *
 * Copyright (C) 2011 noptrix - http://www.noptrix.net/                        *
 *                                                                             *
 * This program is free software: you can redistribute it and/or modify        *
 * it under the terms of the GNU General Public License as published by        *
 * the Free Software Foundation, either version 3 of the License, or           *
 * (at your option) any later version.                                         *
 *                                                                             *
 * This program is distributed in the hope that it will be useful,             *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               *
 * GNU General Public License for more details.                                *
 *                                                                             *
 * You should have received a copy of the GNU General Public License           *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.       *
 *                                                                             *
 ******************************************************************************/

#ifndef __JOB_H__
#define __JOB_H__


#include "sshtrix.h"


/* max user and pass len + 1 (0x00) */
#define MAX_USER_LEN        128 + 1
#define MAX_PASS_LEN        128 + 1

/* default settings */
#define DEFAULT_PORT        22
#define CONN_TIMEOUT        3
#define DELAY               0
#define NUM_THREADS         4
#define FIRST_FOUND_ON      1
#define FIRST_FOUND_OFF     0
#define PRINT_LOGIN_ON      1
#define PRINT_LOGIN_OFF     0
#define VERBOSE             1


/* target related stuff */
typedef struct {
    char *host;             /* target ipaddr or hostname */
    uint16_t port;          /* target port */
} target_t;

/* user and pass related stuff */
typedef struct {
    char *user_list;                /* user filename */
    char *pass_list;                /* pass filename */
    char **users;                   /* all users */
    char **pass;                    /* all passwords */
    char **found_users;             /* found users */
    char **found_pass;              /* found passwords */
    unsigned long int num_users;    /* number of users we have */
    unsigned long int num_pass;     /* number of passwords we have */
    unsigned long int num_found;    /* found logins */
} list_t;

/* our job {}  */
typedef struct {
    char *logfile;                      /* log filename for found logins */
    target_t *target;                   /* ptr to target_t {} */
    list_t *list;                       /* ptr to list_t {} */
    unsigned short int conn_timeout;    /* tcp connect() timeout */
    unsigned short int delay;           /* delay before next try */
    unsigned int num_threads;           /* number of threads */
    unsigned char first;                /* exit if first found pair */
    unsigned char print_login;          /* immediatelly print found logins */
    unsigned char verbose;              /* verbosity, default off */
    unsigned long int time;             /* for duration */
} job_t;


job_t *alloc_logins(job_t *);
job_t *get_credentials(job_t *);
job_t *get_default_accounts(job_t *);
job_t *set_job_defaults();
void free_job(job_t *);


#endif

/* EOF */
