/*******************************************************************************
 * sshtrix - a very fast multithreaded SSH login cracker                       * 
 *                                                                             *
 * checks.c                                                                    *
 *                                                                             *
 * Copyright (C) 2011 noptrix - http://www.noptrix.net/                        *
 *                                                                             *
 * This program is free software: you can redistribute it and/or modify        *
 * it under the terms of the GNU General Public License as published by        *
 * the Free Software Foundation, either version 3 of the License, or           *
 * (at your option) any later version.                                         *
 *                                                                             *
 * This program is distributed in the hope that it will be useful,             *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               *
 * GNU General Public License for more details.                                *
 *                                                                             *
 * You should have received a copy of the GNU General Public License           *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.       *
 *                                                                             *
 ******************************************************************************/

#include "checks.h"
#include "error.h"
#include "wrapper.h"


/* checks for valid file */
void check_file(const char *file)
{
    FILE *fp = NULL;


    fp = xfopen(file, "r");
    xfclose(fp);

    return;
}


/* checks for valid hosts */
void check_host(const char *host)
{
    int x = 0;
    unsigned char buff[sizeof(struct in_addr)];


    x = inet_pton(AF_INET, host, buff);
    
    if (x <= 0) {
        xgethostbyname(host);
    }

    return;
}


/* checks for valid port range */
void check_port(int port)
{
    if (port == 0 || port < 0 || port > 65535) {
        print_error(ERR_PORT);
    }

    return;
}


/* check first usage */
void check_argc(int argc)
{
    if (argc < 2) {
        print_error(ERR_ARGC);
    }
    
    return;
}


/* checks, if necessary arguments are selected */
void check_args(job_t *job)
{
    if (!(job->target->host) || !(job->list->user_list) ||
        !(job->list->pass_list)) {
        print_error(ERR_ARGS);
    }

    return;
}


/* check if num_threads > 256. if so, warn user */
void check_threads(unsigned int threads)
{
    unsigned int i = 3;
    unsigned int j = 0;


    if (threads > 256) {
        print_error(ERR_THREADS);
        fprintf(stderr, "--- CTRL+C to stop: ");
        while (i > j) {
            fflush(stderr);
            fprintf(stderr, "%d  \b", i);
            sleep(1);
            --i;
        }
        printf("\n--- you are crazy...\n");
    }

    return;
}

/* EOF */
