/*******************************************************************************
 *  sshtrix - a very fast multithreaded SSH login cracker                      *
 *                                                                             *
 * job.c                                                                       *
 *                                                                             *
 * Copyright (C) 2011 noptrix - http://www.noptrix.net/                        *
 *                                                                             *
 * This program is free software: you can redistribute it and/or modify        *
 * it under the terms of the GNU General Public License as published by        *
 * the Free Software Foundation, either version 3 of the License, or           *
 * (at your option) any later version.                                         *
 *                                                                             *
 * This program is distributed in the hope that it will be useful,             *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               *
 * GNU General Public License for more details.                                *
 *                                                                             *
 * You should have received a copy of the GNU General Public License           *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.       *
 *                                                                             *
 ******************************************************************************/

#include "job.h"
#include "file.h"



static job_t *alloc_structs(job_t *);


/* read in usenames and passwords line by line */
job_t *get_credentials(job_t *job)
{
    /* usernames */
    job->list->num_users = count_lines(job->list->user_list);
    job->list->users = read_lines(job->list->user_list, job->list->num_users);
    
    /* passwords */
    job->list->num_pass = count_lines(job->list->pass_list);
    job->list->pass = read_lines(job->list->pass_list, job->list->num_pass);
    
    return job;
}


/* allocate memory for found login pairs */
job_t *alloc_logins(job_t *job)
{
    /* for found users */
    job->list->found_users = 
        (char **) alloc_buff(job->list->num_users * job->list->num_pass *
                             sizeof(char *));
    
    /* for found passwords */
    job->list->found_pass =
        (char **) alloc_buff(job->list->num_pass * job->list->num_users *
                             sizeof(char *));
    
    return job;
}


/* free job {} */
void free_job(job_t *job)
{
    unsigned long int i = 0;


    for (i = 0; i < job->list->num_users; i++) {
        free(job->list->users[i]);
    }
    for (i = 0; i < job->list->num_pass; i++) {
        free(job->list->pass[i]);
    }
    free(job->list->found_users);
    free(job->list->found_pass);
    free(job->list->users);
    free(job->list->pass);
    free(job->list);
    free(job->target);
    free(job);

    return;
}


/* allocate memory for each {} */
static job_t *alloc_structs(job_t *job)
{
    job = (job_t *) alloc_buff(sizeof(job_t));
    job->target = (target_t *) alloc_buff(sizeof(target_t));
    job->list = (list_t *) alloc_buff(sizeof(list_t));
   
    return job;
}


/* default settings for job {} - prior to our complete definition */
job_t *set_job_defaults()
{
    job_t *job;


    job = alloc_structs(job);

    job->target->port = DEFAULT_PORT;
    job->conn_timeout = CONN_TIMEOUT;
    job->delay = DELAY;
    job->num_threads = NUM_THREADS;
    job->first = FIRST_FOUND_OFF;
    job->print_login = PRINT_LOGIN_OFF;

    return job;
}

/* EOF */
