/*******************************************************************************
 * sshtrix - a very fast multithreaded SSH login cracker                       *
 *                                                                             *
 * sshtrix.c                                                                   *
 *                                                                             *
 * Copyright (C) 2011 noptrix - http://www.noptrix.net/                        *
 *                                                                             *
 * This program is free software: you can redistribute it and/or modify        *
 * it under the terms of the GNU General Public License as published by        *
 * the Free Software Foundation, either version 3 of the License, or           *
 * (at your option) any later version.                                         *
 *                                                                             *
 * This program is distributed in the hope that it will be useful,             *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               *
 * GNU General Public License for more details.                                *
 *                                                                             *
 * You should have received a copy of the GNU General Public License           *
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.       *
 *                                                                             *
 ******************************************************************************/

#include "sshtrix.h"
#include "checks.h"
#include "job.h"
#include "init.h"
#include "help.h"
#include "report.h"

#include <getopt.h>


/* let's go... */
int main(int argc, char *argv[])
{
    int c = 0;
    job_t *job = NULL;


    /* very important */
    banner();
    check_argc(argc);
    job = set_job_defaults();

    while ((c = getopt(argc, argv, "h:p:l:k:c:w:t:f:esvVH")) != -1) {
        switch (c) {
            case 'h':
                check_host(optarg);
                job->target->host = optarg;
                break;
            case 'p':
                check_port(ATOI(optarg));
                job->target->port = (uint16_t) ATOI(optarg);
                break;
            case 'l':
                check_file(optarg);
                job->list->user_list = optarg;
                break;
            case 'k':
                check_file(optarg);
                job->list->pass_list = optarg;
                break;
            case 'c':
                job->conn_timeout = (unsigned short int) ATOI(optarg);
                break;
            case 'w':
                job->delay = (unsigned short int) ATOI(optarg);
                break;
            case 't':
                check_threads((unsigned int) ATOI(optarg));
                job->num_threads = (unsigned int) ATOI(optarg);
                break;
            case 'f':
                job->logfile = optarg;
                break;
            case 'e':
                job->first = FIRST_FOUND_ON;
                break;
            case 's':
                job->print_login = PRINT_LOGIN_ON;
                break;
            case 'v':
                job->verbose = (unsigned char) VERBOSE;
                break;
         case 'V':
             puts(VERSION);
             __EXIT_SUCCESS;
             break;
         case 'H':
             usage();
             __EXIT_SUCCESS;
         default:
             __EXIT_FAILURE;
        }
    }

    check_args(job);
    if (job->verbose) {
        printf("[+] "BLUE"reading usernames and passwords\n"NORM"");
    }

    /* whole action begins here */
    job = get_credentials(job);
    job = alloc_logins(job);
    job = init(job);
    job = report(job);
    free_job(job);

    return 0;
}

/* EOF */
